# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/NetworkStateCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.devices.generic.NetworkState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/NetworkStateCollection.proto',
  package='rst.devices.generic',
  serialized_pb='\n0rst/devices/generic/NetworkStateCollection.proto\x12\x13rst.devices.generic\x1a&rst/devices/generic/NetworkState.proto\"L\n\x16NetworkStateCollection\x12\x32\n\x07\x65lement\x18\x01 \x03(\x0b\x32!.rst.devices.generic.NetworkStateB\x1c\x42\x1aNetworkStateCollectionType')




_NETWORKSTATECOLLECTION = _descriptor.Descriptor(
  name='NetworkStateCollection',
  full_name='rst.devices.generic.NetworkStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.generic.NetworkStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=113,
  serialized_end=189,
)

_NETWORKSTATECOLLECTION.fields_by_name['element'].message_type = rst.devices.generic.NetworkState_pb2._NETWORKSTATE
DESCRIPTOR.message_types_by_name['NetworkStateCollection'] = _NETWORKSTATECOLLECTION

class NetworkStateCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _NETWORKSTATECOLLECTION

  # @@protoc_insertion_point(class_scope:rst.devices.generic.NetworkStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\032NetworkStateCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/Torques.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/Torques.proto',
  package='rst.dynamics',
  serialized_pb='\n\x1arst/dynamics/Torques.proto\x12\x0crst.dynamics\"*\n\x07Torques\x12\t\n\x01\x61\x18\x01 \x02(\x02\x12\t\n\x01\x62\x18\x02 \x02(\x02\x12\t\n\x01\x63\x18\x03 \x02(\x02\x42\rB\x0bTorquesType')




_TORQUES = _descriptor.Descriptor(
  name='Torques',
  full_name='rst.dynamics.Torques',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='rst.dynamics.Torques.a', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='rst.dynamics.Torques.b', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='rst.dynamics.Torques.c', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=44,
  serialized_end=86,
)

DESCRIPTOR.message_types_by_name['Torques'] = _TORQUES

class Torques(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TORQUES

  # @@protoc_insertion_point(class_scope:rst.dynamics.Torques)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\013TorquesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/ObjectCollisionCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.ObjectCollision_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/ObjectCollisionCollection.proto',
  package='rst.kinematics',
  serialized_pb='\n.rst/kinematics/ObjectCollisionCollection.proto\x12\x0erst.kinematics\x1a$rst/kinematics/ObjectCollision.proto\"M\n\x19ObjectCollisionCollection\x12\x30\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1f.rst.kinematics.ObjectCollisionB\x1f\x42\x1dObjectCollisionCollectionType')




_OBJECTCOLLISIONCOLLECTION = _descriptor.Descriptor(
  name='ObjectCollisionCollection',
  full_name='rst.kinematics.ObjectCollisionCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.kinematics.ObjectCollisionCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=104,
  serialized_end=181,
)

_OBJECTCOLLISIONCOLLECTION.fields_by_name['element'].message_type = rst.kinematics.ObjectCollision_pb2._OBJECTCOLLISION
DESCRIPTOR.message_types_by_name['ObjectCollisionCollection'] = _OBJECTCOLLISIONCOLLECTION

class ObjectCollisionCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _OBJECTCOLLISIONCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.kinematics.ObjectCollisionCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\035ObjectCollisionCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/SpatialAccelerationsCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.SpatialAccelerations_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/SpatialAccelerationsCollection.proto',
  package='rst.kinematics',
  serialized_pb='\n3rst/kinematics/SpatialAccelerationsCollection.proto\x12\x0erst.kinematics\x1a)rst/kinematics/SpatialAccelerations.proto\"W\n\x1eSpatialAccelerationsCollection\x12\x35\n\x07\x65lement\x18\x01 \x03(\x0b\x32$.rst.kinematics.SpatialAccelerationsB$B\"SpatialAccelerationsCollectionType')




_SPATIALACCELERATIONSCOLLECTION = _descriptor.Descriptor(
  name='SpatialAccelerationsCollection',
  full_name='rst.kinematics.SpatialAccelerationsCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.kinematics.SpatialAccelerationsCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=114,
  serialized_end=201,
)

_SPATIALACCELERATIONSCOLLECTION.fields_by_name['element'].message_type = rst.kinematics.SpatialAccelerations_pb2._SPATIALACCELERATIONS
DESCRIPTOR.message_types_by_name['SpatialAccelerationsCollection'] = _SPATIALACCELERATIONSCOLLECTION

class SpatialAccelerationsCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SPATIALACCELERATIONSCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.kinematics.SpatialAccelerationsCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\"SpatialAccelerationsCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointVelocitiesCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.JointVelocities_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointVelocitiesCollection.proto',
  package='rst.kinematics',
  serialized_pb='\n.rst/kinematics/JointVelocitiesCollection.proto\x12\x0erst.kinematics\x1a$rst/kinematics/JointVelocities.proto\"M\n\x19JointVelocitiesCollection\x12\x30\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1f.rst.kinematics.JointVelocitiesB\x1f\x42\x1dJointVelocitiesCollectionType')




_JOINTVELOCITIESCOLLECTION = _descriptor.Descriptor(
  name='JointVelocitiesCollection',
  full_name='rst.kinematics.JointVelocitiesCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.kinematics.JointVelocitiesCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=104,
  serialized_end=181,
)

_JOINTVELOCITIESCOLLECTION.fields_by_name['element'].message_type = rst.kinematics.JointVelocities_pb2._JOINTVELOCITIES
DESCRIPTOR.message_types_by_name['JointVelocitiesCollection'] = _JOINTVELOCITIESCOLLECTION

class JointVelocitiesCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTVELOCITIESCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.kinematics.JointVelocitiesCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\035JointVelocitiesCollectionType')
# @@protoc_insertion_point(module_scope)
